==> evaics-0.2.17.tar.gz: evaics-0.2.17/evaics/client/cloud.py <==
class Client:

    def __init__(self, client):
        self.client = client
        self.node_map = None
        self.system_name = None

    def prepare(self):
        self.system_name = self.client.test().system_name
        self.node_map = {
            n['name']: n['svc']
            for n in self.client.bus_call('node.list')
            if n['remote'] is True
        }

    def bus_call(self,
                 method: str,
                 params: dict = None,
                 target='eva.core',
                 node=None):
        """
        Call BUS/RT EAPI method

        Requires admin permissions

        Args:
            method: API method

        Optional:
            params: API method parameters (dict)
            target: target service (default: eva.core)
            node: target node (.local can be used for the local)

        Returns:
            API response payload
        """
        if self.system_name is None:
            raise RuntimeError('client not prepared')
        if node is None or node == '.local':
            return self.client.bus_call(method, params, target)
        else:
            try:
                target_repl_svc = self.node_map[node]
            except KeyError:
                raise RuntimeError(f'node {node} is unknown')
            if params is None:
                params = {}
            params['node'] = node
            return self.client.bus_call(f'bus::{target}::{method}',
                                        params,
                                        target=target_repl_svc)

==> evaics-0.2.18.tar.gz: evaics-0.2.18/evaics/client/cloud.py <==
class Client:

    def __init__(self, client):
        self.client = client
        self.node_map = None
        self.system_name = None

    def prepare(self):
        self.system_name = self.client.test().system_name
        self.node_map = {
            n['name']: n['svc']
            for n in self.client.bus_call('node.list')
            if n['remote'] is True
        }

    def bus_call(self,
                 method: str,
                 params: dict = None,
                 target='eva.core',
                 node=None):
        """
        Call BUS/RT EAPI method

        Requires admin permissions

        Args:
            method: API method

        Optional:
            params: API method parameters (dict)
            target: target service (default: eva.core)
            node: target node (.local can be used for the local)

        Returns:
            API response payload
        """
        if self.system_name is None:
            raise RuntimeError('client not prepared')
        if node is None or node == '.local' or node == self.system_name:
            return self.client.bus_call(method, params, target)
        else:
            try:
                target_repl_svc = self.node_map[node]
            except KeyError:
                raise RuntimeError(f'node {node} is unknown')
            if params is None:
                params = {}
            params['node'] = node
            return self.client.bus_call(f'bus::{target}::{method}',
                                        params,
                                        target=target_repl_svc)
